@@ -75,11 +75,11 @@ impl AppLogger {
 
 /// Trait defining the logging format and destination.
 impl log::Log for AppLogger {
-    fn enabled(&self, metadata: &Metadata) -> bool {
+    fn enabled(&self, metadata: &Metadata<'_>) -> bool {
         metadata.level() <= Level::Trace
     }
 
-    fn log(&self, record: &Record) {
+    fn log(&self, record: &Record<'_>) {
         if self.enabled(record.metadata()) {
             // Log this to `stderr`.
             eprintln!("*** {}: {}", record.level(), record.args());
